const { promisify } = require('util');
const { dirname, join } = require('path');
const { copyFile, mkdir, stat } = require('fs');
const { totalist } = require('totalist');

const pCopyFile = promisify(copyFile)
const pMkdir = promisify(mkdir)
const pStat = promisify(stat)

const mergefs = async ({ input, output, single }) => {
	const fileMap = {}

	for (const inputFolder of (input || [])) {
		if (single) {
			try {
				const stats = await pStat(join(inputFolder, single))
				if (!stats.isDirectory()) {
					fileMap[single] = inputFolder
				}
			} catch (ignore) {}
		} else {
			await totalist(inputFolder, name => {
				fileMap[name] = inputFolder
			})
		}
	}

	for (const [ file, inputFolder ] of Object.entries(fileMap)) {
		await pMkdir(dirname(join(output, file)), { recursive: true })
		await pCopyFile(join(inputFolder, file), join(output, file))
	}
}

exports.mergefs = mergefs;